@@ -77,7 +77,7 @@ expresso <- function(afbatch,
     }
 
   if (widget) {
-    require(tkWidgets) || stop("library tkWidgets could not be found !")
+    requireNamespace("tkWidgets")
   }
 
   nchips <- length(afbatch)
@@ -107,7 +107,7 @@ expresso <- function(afbatch,
     if (verbose)
       cat("background correcting...")
 
-    afbatch <- do.call(affy:::bg.correct, c(alist(afbatch, method=bgcorrect.method), bgcorrect.param))
+    afbatch <- do.call("bg.correct", c(alist(afbatch, method=bgcorrect.method), bgcorrect.param))
 
     if (verbose)
       cat("done.\n")
